.. arcus.ml documentation master file, created by
   sphinx-quickstart on Thu Dec  9 09:02:08 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to arcus.ml's documentation!
====================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   arcus


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
